=======
Credits
=======

Development Lead
----------------

* Marc-Olivier Buob <marc-olivier.buob@nokia-bell-labs.com>
* Maxime Raynal <maxime.raynal@nokia.com>

Contributors
------------

* Georges Quénot <georges.quenot@imag.fr>
